@@ -49,33 +49,59 @@ EnvironmentLifecycleTypeDef = TypedDict(
     total=False,
 )
 
-EnvironmentMemberTypeDef = TypedDict(
-    "EnvironmentMemberTypeDef",
+_RequiredEnvironmentMemberTypeDef = TypedDict(
+    "_RequiredEnvironmentMemberTypeDef",
     {
         "permissions": Literal["owner", "read-write", "read-only"],
         "userId": str,
         "userArn": str,
         "environmentId": str,
-        "lastAccess": datetime,
     },
-    total=False,
+)
+_OptionalEnvironmentMemberTypeDef = TypedDict(
+    "_OptionalEnvironmentMemberTypeDef", {"lastAccess": datetime}, total=False
 )
 
-EnvironmentTypeDef = TypedDict(
-    "EnvironmentTypeDef",
+
+class EnvironmentMemberTypeDef(
+    _RequiredEnvironmentMemberTypeDef, _OptionalEnvironmentMemberTypeDef
+):
+    pass
+
+
+_RequiredEnvironmentTypeDef = TypedDict(
+    "_RequiredEnvironmentTypeDef", {"type": Literal["ssh", "ec2"], "arn": str, "ownerArn": str}
+)
+_OptionalEnvironmentTypeDef = TypedDict(
+    "_OptionalEnvironmentTypeDef",
     {
         "id": str,
         "name": str,
         "description": str,
-        "type": Literal["ssh", "ec2"],
         "connectionType": Literal["CONNECT_SSH", "CONNECT_SSM"],
-        "arn": str,
-        "ownerArn": str,
         "lifecycle": "EnvironmentLifecycleTypeDef",
+        "managedCredentialsStatus": Literal[
+            "ENABLED_ON_CREATE",
+            "ENABLED_BY_OWNER",
+            "DISABLED_BY_DEFAULT",
+            "DISABLED_BY_OWNER",
+            "DISABLED_BY_COLLABORATOR",
+            "PENDING_REMOVAL_BY_COLLABORATOR",
+            "PENDING_START_REMOVAL_BY_COLLABORATOR",
+            "PENDING_REMOVAL_BY_OWNER",
+            "PENDING_START_REMOVAL_BY_OWNER",
+            "FAILED_REMOVAL_BY_COLLABORATOR",
+            "FAILED_REMOVAL_BY_OWNER",
+        ],
     },
     total=False,
 )
 
+
+class EnvironmentTypeDef(_RequiredEnvironmentTypeDef, _OptionalEnvironmentTypeDef):
+    pass
+
+
 TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str})
 
 CreateEnvironmentEC2ResultTypeDef = TypedDict(
@@ -83,9 +109,7 @@ CreateEnvironmentEC2ResultTypeDef = TypedDict(
 )
 
 CreateEnvironmentMembershipResultTypeDef = TypedDict(
-    "CreateEnvironmentMembershipResultTypeDef",
-    {"membership": "EnvironmentMemberTypeDef"},
-    total=False,
+    "CreateEnvironmentMembershipResultTypeDef", {"membership": "EnvironmentMemberTypeDef"}
 )
 
 DescribeEnvironmentMembershipsResultTypeDef = TypedDict(
@@ -102,7 +126,6 @@ DescribeEnvironmentStatusResultTypeDef = TypedDict(
         ],
         "message": str,
     },
-    total=False,
 )
 
 DescribeEnvironmentsResultTypeDef = TypedDict(
